package com.zt.plat.module.base.service.businessdictionarytype;

import java.util.*;
import jakarta.validation.*;
import com.zt.plat.module.base.controller.admin.businessdictionarytype.vo.*;
import com.zt.plat.module.base.dal.dataobject.businessdictionarytype.BusinessDictionaryTypeDO;
import com.zt.plat.module.base.dal.dataobject.businessdictionarytype.BusinessDictionaryDataDO;
import com.zt.plat.framework.common.pojo.PageResult;

/**
 * 业务字典类型 Service 接口
 *
 * @author 后台管理
 */
public interface BusinessDictionaryTypeService {

    /**
     * 创建业务字典类型
     *
     * @param createReqVO 创建信息
     * @return 编号
     */
    BusinessDictionaryTypeRespVO createBusinessDictionaryType(@Valid BusinessDictionaryTypeSaveReqVO createReqVO);

    /**
     * 更新业务字典类型
     *
     * @param updateReqVO 更新信息
     */
    void updateBusinessDictionaryType(@Valid BusinessDictionaryTypeSaveReqVO updateReqVO);

    /**
     * 删除业务字典类型
     *
     * @param id 编号
     */
    void deleteBusinessDictionaryType(Long id);

    /**
    * 批量删除业务字典类型
    *
    * @param ids 编号
    */
    void deleteBusinessDictionaryTypeListByIds(List<Long> ids);

    /**
     * 获得业务字典类型
     *
     * @param id 编号
     * @return 业务字典类型
     */
    BusinessDictionaryTypeDO getBusinessDictionaryType(Long id);

    /**
     * 获得业务字典类型分页
     *
     * @param pageReqVO 分页查询
     * @return 业务字典类型分页
     */
    PageResult<BusinessDictionaryTypeDO> getBusinessDictionaryTypePage(BusinessDictionaryTypePageReqVO pageReqVO);

    // ==================== 子表（业务字典数据） ====================

    /**
     * 获得业务字典数据列表
     *
     * @param dictionaryTypeId 字典类型
     * @return 业务字典数据列表
     */
    List<BusinessDictionaryDataDO> getBusinessDictionaryDataListByDictionaryTypeId(Long dictionaryTypeId);

    /**
     * 根据字典类型编码获取业务字典数据列表
     *
     * @param type 字典类型编码
     * @return 字典数据列表
     */
    List<BusinessDictionaryDataDO> getBusinessDictionaryDataListByType(String type);

}